---
title: autostart
keywords: documentation
layout: documentation
sidebar: mq_install_sidebar
toc: false
---
## Overview

The defined type `mq_install::autostart` allows you to create a systemd startup unit for a specified MQ queue manager and
make sure it is restarted after a system reboot.

The simples way to use it is:

``` puppet
mq_install::autostart{'QM1':}
```

Here is an example with all possible properties used:

``` puppet
mq_install::autostart{'QM1':
    path         => '/etc/systemd/system',
    service_name => 'my_mq,
    mq_version   => 8,
    mq_user      => 'mqm_user',
    mq_group     => 'mqm_group',
    nofile_limit => 20480,
    nproc_limit  => 4096,
}
```





## Attributes



Attribute Name                              | Short Description                                                                        |
------------------------------------------- | ---------------------------------------------------------------------------------------- |
[mq_group](#autostart_mq_group)             | Allows you to specify the OS group the queue manage will be started under.               |
[mq_user](#autostart_mq_user)               | Allows you to specify the OS user the queue manage will be started under.                |
[mq_version](#autostart_mq_version)         | Allows you to specify the MQ versions.                                                   |
[multi_instance](#autostart_multi_instance) | When `true` the queue manager wll be started in multi instance mode.                     |
[nofile_limit](#autostart_nofile_limit)     | The nofile limit used for the process running the queue manager.                         |
[nproc_limit](#autostart_nproc_limit)       | The nproc limit used for the process running the queue manager.                          |
[path](#autostart_path)                     | Allows you to specify the path where the unit-file will be placed.                       |
[service_name](#autostart_service_name)     | Allows you to specfy the name of the service.                                            |
[title](#autostart_title)                   | The title is used to specfy the name of the queue manaer you want to ensure autostarted. |




### title<a name='autostart_title'>

The title is used to specfy the name of the queue manaer you want to ensure autostarted.

Here is an example on how to use this:

``` puppet
mq_install::autostart{'QM1':
}
```


[Back to overview of autostart](#attributes)

### path<a name='autostart_path'>

Allows you to specify the path where the unit-file will be placed.

Here is an example on how to use this:

``` puppet
mq_install::autostart{'QM1':
  ...
  path         => '/etc/mysystemd/system',
  ...
}
```

The default value is `/etc/systemd/system'.

Type: `String[1]`

Default:`lookup('mq_install::autostart::path')`

[Back to overview of autostart](#attributes)

### service_name<a name='autostart_service_name'>

Allows you to specfy the name of the service.

Here is an example on how to use this:

``` puppet
mq_install::autostart{'QM1':
  ...
  service_name => 'my_mq,
  ...
}
```

The default value is : `"mq@$queuemanager_name`.
Type: `String[1]`

Default:`lookup('mq_install::autostart::service_name')`

[Back to overview of autostart](#attributes)

### mq_version<a name='autostart_mq_version'>

Allows you to specify the MQ versions.

At this point in time it is only used for comments in the unit.

Here is an example on how to use this:

``` puppet
mq_install::autostart{'QM1':
  ...
  mq_version   => 8,
  ...
}
```

Type: `Integer`

Default:`lookup('mq_install::autostart::mq_version')`

[Back to overview of autostart](#attributes)

### mq_user<a name='autostart_mq_user'>

Allows you to specify the OS user the queue manage will be started under.

Here is an example on how to use this:

``` puppet
mq_install::autostart{'QM1':
  ...
  mq_user      => 'mqm_user',
  ...
}
```

The default value is `mqm` and is correct in most situations.
Type: `String[1]`

Default:`lookup('mq_install::autostart::mq_user')`

[Back to overview of autostart](#attributes)

### mq_group<a name='autostart_mq_group'>

Allows you to specify the OS group the queue manage will be started under.

Here is an example on how to use this:

``` puppet
mq_install::autostart{'QM1':
  ...
  mq_group     => 'mqm_group',
  ...
}
```

The default value is `mqm` and is correct in most situations.
Type: `String[1]`

Default:`lookup('mq_install::autostart::mq_group')`

[Back to overview of autostart](#attributes)

### nofile_limit<a name='autostart_nofile_limit'>

The nofile limit used for the process running the queue manager.

Here is an example on how to use this:

``` puppet
mq_install::autostart{'QM1':
  ...
  nofile_limit => 20480,
  ...
}
```

Type: `Integer`

Default:`lookup('mq_install::os::nofile')`

[Back to overview of autostart](#attributes)

### nproc_limit<a name='autostart_nproc_limit'>

The nproc limit used for the process running the queue manager.

Here is an example on how to use this:

``` puppet
mq_install::autostart{'QM1':
  path         => '/etc/systemd/system',
  service_name => 'my_mq,
  mq_version   => 8,
  mq_user      => 'mqm_user',
  mq_group     => 'mqm_group',
  nofile_limit => 20480,
  nproc_limit  => 4096,
}
```

Type: `Integer`

Default:`lookup('mq_install::os::nproc')`

[Back to overview of autostart](#attributes)

### multi_instance<a name='autostart_multi_instance'>

When `true` the queue manager wll be started in multi instance mode.

Here is an example on how to use this:

``` puppet
mq_install::autostart{'QM1':
  ...
  multi_instance => true,
  ...
}
```

Type: `Boolean`

Default:`lookup('mq_install::autostart::multi_instance')`

[Back to overview of autostart](#attributes)
