#
# See the file "LICENSE" for the full license governing this code.
#
#
# Create array of selected packages. First parameter is the set of base packages,
# They must always be selected.
# Second parameter is an array of selections. The third parameter is an array of packages,
# belonging to the selection.
#
Puppet::Functions.create_function(:"mq_install::selected_packages") do
  dispatch :selected_packages do
    required_param 'Array[String[1]]', :base_packages
    required_param 'Array[Boolean]', :selection
    required_param 'Array[Variant[String[1], Array[String[1]]]]', :packages
    # Because we want to be compatible with Puppet 4.0, we cannot use the
    # return_type yet.
    # TODO: Add this when we lose support for Puppet 4.0
    # return_type 'Array'
  end

  #
  # return full selection of packages
  #
  def selected_packages(base_packages, selection, packages)
    fail 'selection and packages array need to be same length' if selection.size != packages.size

    selected_packages = base_packages
    index = 0
    while index < selection.size
      selected_packages << packages[index] if selection[index]
      index += 1
    end
    selected_packages.compact.flatten
  end
end
